#
# db2_secured::controls::disable_database_discoverability
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThe `DISCOVER_DB` parameter specifies whether the database can be discovered in the network. It is recommended that databases not be discoverable.## RationaleDiscovery capabilities may be used by a malicious entity to derive the names of and target Db2 databases.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `db2_secured::controls::disable_database_discoverability: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `disable_database_discoverability` to the array value `db2_secured::skip_list` in your hiera data.  ## BenchmarksThis control is used in the following benchmarks:- [db11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 4.1.15
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::disable_database_discoverability () {
  db2_secured_setup { "disable_database_discoverability on ${title}":
    ensure => 'present',
  }

  resource_value { "Db2_database[${title}]discover_db":
    allow_create   => true,
    allow_redefine => true,
    value          => 'DISABLE',
  }
}
