#
# db2_secured::controls::disable_grants_during_restore
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThe `DB2_RESTORE_GRANT_ADMIN_AUTHORITIES` registry variable determines whether the authorization ID of the user performing a restore is granted administrative authorities (`SECADM`, `DBADM`, `DATAACCESS`, and `ACCESSCTRL` authorities) on the restored database. It is typically used when restoring a database on a server where the original database creator account does not exist. It is recommended that this variable not be set except when specifically performing a restore where you wish these privileges to be granted so they are not accidentally granted.## RationaleUse of this registry variable may grant administrative authorities accidentally if the value is left on during normal operations and a restore is run.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `db2_secured::controls::disable_grants_during_restore: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `disable_grants_during_restore` to the array value `db2_secured::skip_list` in your hiera data.  ## BenchmarksThis control is used in the following benchmarks:- [db11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 3.2.3
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::disable_grants_during_restore {
  db2_secured_setup { "disable_grants_during_restore on ${title}":
    ensure => 'present',
  }

  -> db2_secured::internal::ensure_registry_value { "${title}/DB2_RESTORE_GRANT_ADMIN_AUTHORITIES":
    value => 'OFF',
  }
}
