#
# db2_secured::controls::enable_automatic_database_maintenance
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlEnable automatic database maintenance on your DB2 instance. It is recommended that the DB2 Automatic Maintenance tool be used to ensure that the instance is performing optimally.## RationaleA well-maintained DB2 instance will provide access to the data and reduce database outages.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `db2_secured::controls::enable_automatic_database_maintenance: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `enable_automatic_database_maintenance` to the array value `db2_secured::skip_list` in your hiera data.  ## BenchmarksThis control is used in the following benchmarks:- [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 5.3
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::enable_automatic_database_maintenance {
  db2_secured_setup { "enable_automatic_database_maintenance on ${title}":
    ensure => 'present',
  }

  resource_value { "Db2_database[${title}]auto_maint":
    allow_create   => true,
    allow_redefine => true,
    value          => 'ON',
  }
}
