#
# db2_secured::controls::enable_extended_security
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThe `DB2_EXTSECURITY` registry variable determines whether extended security is enabled on Windows. Extended security enables file permissions for all Db2 objects so they can be accessed by users in `DB2ADMNS` and `DB2USERS` groups. It is recommended that extended security be enabled.This registry variable only applies to Db2 Servers running on Windows.## RationaleExtended security provides file permission protection for Db2 objects when running in a multi-user environment.## ImpactBefore enabling extended security for an existing installation, you should ensure you have added users to the `DB2ADMNS` and `DB2USERS` groups so that you are able to access Db2 once the permission have been applied. Once extended security is enabled, it is not recommended to be directly disabled, instead a full re-install should be used.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `db2_secured::controls::enable_extended_security: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `enable_extended_security` to the array value `db2_secured::skip_list` in your hiera data.  ## BenchmarksThis control is used in the following benchmarks:- [db11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 3.2.4
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::enable_extended_security {
  db2_secured_setup { "enable_extended_security on ${title}":
    ensure => 'present',
  }
  if $facts['kernel'] == 'Windows' {
    alert('Specified CIS control is not yet automatically enforced.')
  } else {
    debug('Specified CIS control is not applicable on current kernel')
  }
}
