#
# db2_secured::controls::enable_server_based_authentication
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThe `srvcon_auth` parameter specifies how and where authentication is to take place for incoming connections to the server. It is recommended that this parameter is not set to CLIENT.## RationaleThis parameter will take precedence over and override the authentication level. Authentication should be set on the server side.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `db2_secured::controls::enable_server_based_authentication: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `enable_server_based_authentication` to the array value `db2_secured::skip_list` in your hiera data.  ## BenchmarksThis control is used in the following benchmarks:- [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 3.1.13
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::enable_server_based_authentication {
  $elements = $title.split('/')
  $instance = $elements[0]

  db2_secured_setup { "enable_server_based_authentication on ${title}":
    ensure => 'present',
  }

  resource_value { "Db2_instance[${instance}]srvcon_auth/1":
    allow_create   => true,
    allow_redefine => true,
    value          => 'SERVER',
  }
}
