#
# db2_secured::controls::enable_ssl_communication_with_ldap_server
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThe communication layer between a DB2 instance and the LDAP server should be encrypted. It is recommended that the `ENABLE_SSL` parameter in the `IBMLDAPSecurity.ini` file be set to TRUE.## RationaleEnabling SSL will help ensure the confidentiality of authentication credentials and other information that is sent between the DB2 instance and the LDAP server.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `db2_secured::controls::enable_ssl_communication_with_ldap_server: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `enable_ssl_communication_with_ldap_server` to the array value `db2_secured::skip_list` in your hiera data.  ## BenchmarksThis control is used in the following benchmarks:- [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 9.5
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::enable_ssl_communication_with_ldap_server {
  $elements = $title.split('/')
  $instance = $elements[0]
  $database = $elements[1]

  db2_secured_setup { "enable_ssl_communication_with_ldap_server on ${title}":
    ensure => 'present',
  }

  alert('Specified CIS control is not yet automatically enforced.')
}
