#
# db2_secured::controls::encrypt_user_data_across_the_network
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlDB2 supports a number of authentication mechanisms. It is recommended that the DATA_ENCRYPT authentication mechanism be used.## RationaleThe `DATA_ENCRYPT` authentication mechanism employs cryptographic algorithms to protect the confidentiality of authentication credentials and user data as they traverse the network between the DB2 client and server.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `db2_secured::controls::encrypt_user_data_across_the_network: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `encrypt_user_data_across_the_network` to the array value `db2_secured::skip_list` in your hiera data.  ## BenchmarksThis control is used in the following benchmarks:- [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 3.1.2
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::encrypt_user_data_across_the_network {
  $elements = $title.split('/')
  $instance = $elements[0]

  db2_secured_setup { "encrypt_user_data_across_the_network on ${title}":
    ensure => 'present',
  }

  resource_value { "Db2_instance[${instance}]authentication":
    allow_create   => true,
    allow_redefine => true,
    value          => 'DATA_ENCRYPT',
  }
}
