#
# db2_secured::controls::nested_roles
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThe user-defined roles in DB2 can be nested in the same fashion as Windows security groups--a nested group has both its directly assigned permissions as well as the assigned group permissions. By nesting roles, the database administrator is saving time by only having to assign a group of users versus assigning them individually. Nesting roles properly can often ease the application of the security model if it's kept fairly shallow, and if the roles are logically named. If these are all true, then nesting of roles is a good idea.## RationaleAs tracking multiple levels of permissions can result in unauthorized access to data resources, this capability should be restricted according to the needs of the business.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `db2_secured::controls::nested_roles: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `nested_roles` to the array value `db2_secured::skip_list` in your hiera data.  ## BenchmarksThis control is used in the following benchmarks:- [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 8.3
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::nested_roles {
  $elements = $title.split('/')
  $instance = $elements[0]
  $database = $elements[1]

  db2_secured_setup { "nested_roles on ${title}":
    ensure => 'present',
  }

  $facts['db2_nested_roles'].each |$data| {
    if $data['instance'] == $instance and $data['database'] == $database {
      $role = $data['name']
      $grantee = $data['grantee']
      db2_exec { "${instance}/${database}/remove nested role ${grantee}":
        statement => "revoke role ${role} from role ${grantee}",
      }
    }
  }
}
