#
# db2_secured::controls::remove_default_databases
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlA DB2 instance may come installed with default databases. It is recommended that the `SAMPLE` database be removed.## RationaleRemoving unused, well-known databases will reduce the attack surface of the system.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `db2_secured::controls::remove_default_databases: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `remove_default_databases` to the array value `db2_secured::skip_list` in your hiera data.  ## BenchmarksThis control is used in the following benchmarks:- [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 9.4
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::remove_default_databases {
  $elements = $title.split('/')
  $instance = $elements[0]
  $database = $elements[1]

  db2_secured_setup { "remove_default_databases on ${title}":
    ensure => 'present',
  }

  -> db2_database { "${instance}/SAMPLE":
    ensure => 'absent',
  }
}
