#
# db2_secured::controls::require_explicit_authorization_for_cataloging
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlDB2 can be configured to allow users that do not possess the `SYSADM` authority to catalog and uncatalog databases and nodes. It is recommended that the `catalog_noauth` parameter be set to `NO`.## RationaleCataloging a database is the process of registering a database from a remote client to allow remote call and access. Setting `catalog_noauth` to `YES` bypasses all permissions checks and allows anyone to catalog and uncatalog databases.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `db2_secured::controls::require_explicit_authorization_for_cataloging: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `require_explicit_authorization_for_cataloging` to the array value `db2_secured::skip_list` in your hiera data.  ## BenchmarksThis control is used in the following benchmarks:- [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 3.1.3- [db11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 3.1.1
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::require_explicit_authorization_for_cataloging {
  $elements = $title.split('/')
  $instance = $elements[0]

  db2_secured_setup { "require_explicit_authorization_for_cataloging on ${title}":
    ensure => 'present',
  }

  resource_value { "Db2_instance[${instance}]catalog_noauth":
    allow_create   => true,
    allow_redefine => true,
    value          => 'NO',
  }
}
