#
# db2_secured::controls::restrict_access_to_syscat_surrogateauthids
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThe `SYSCAT.SURROGATEAUTHIDS` contains the names of all accounts that have been granted `SETSESSIONUSER` privilege on a user or to `PUBLIC`. It is recommended that the `PUBLIC` role be restricted from accessing this view.## RationalePublic should not be able to view the names of all the surrogate accounts with `SETSESSIONUSER` privilege.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `db2_secured::controls::restrict_access_to_syscat_surrogateauthids: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `restrict_access_to_syscat_surrogateauthids` to the array value `db2_secured::skip_list` in your hiera data.  ## BenchmarksThis control is used in the following benchmarks:- [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 6.14- [db11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 4.2.37
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::restrict_access_to_syscat_surrogateauthids {
  db2_secured_setup { "restrict_access_to_syscat_surrogateauthids on ${title}":
    ensure => 'present',
  }

  -> db2_secured::internal::revoke_public_grants { "${title}/SYSCAT.SURROGATEAUTHIDS": }
}
