#
# db2_secured::controls::restrict_access_to_sysibm_syssecuritylabelcomponentelements
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThe `SYSIBM.SYSSECURITYLABELCOMPONENTELEMENTS` table contains the element value for security label components. It is recommended that the `PUBLIC`  role be restricted from accessing this table.## RationaleAny databases created without the `RESTRICT` option automatically `GRANT`  the `SELECT`  privilege to `PUBLIC`  for SYSIBM tables. Therefore, it is strongly recommended to explicitly `REVOKE`  the `SELECT`  privilege on the `SYSIBM.SYSSECURITYLABELCOMPONENTELEMENTS` table from `PUBLIC`  to reduce risk to the organization's data.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `db2_secured::controls::restrict_access_to_sysibm_syssecuritylabelcomponentelements: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `restrict_access_to_sysibm_syssecuritylabelcomponentelements` to the array value `db2_secured::skip_list` in your hiera data.  ## BenchmarksThis control is used in the following benchmarks:- [db11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 4.3.28
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::restrict_access_to_sysibm_syssecuritylabelcomponentelements {
  db2_secured_setup { "restrict_access_to_sysibm_syssecuritylabelcomponentelements on ${title}":
    ensure => 'present',
  }

  -> db2_secured::internal::revoke_public_grants { "${title}/SYSIBM.SYSSECURITYLABELCOMPONENTELEMENTS": }
}
