#
# db2_secured::controls::restrict_access_to_sysproc_auth_list_authorities_for_authid
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThe table function `SYSPROC.AUTH_LIST_AUTHORITIES_FOR_AUTHID` returns the instance and database authorities for the specified authorization ID. In a non-restrictive database this table function has `EXECUTE`  granted to public. It is recommended that public should not be able to execute this routine.## RationaleA malicious user may use this function to conduct information gathering regarding users that have high level authorities.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `db2_secured::controls::restrict_access_to_sysproc_auth_list_authorities_for_authid: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `restrict_access_to_sysproc_auth_list_authorities_for_authid` to the array value `db2_secured::skip_list` in your hiera data.  ## BenchmarksThis control is used in the following benchmarks:- [db11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 4.4.4
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::restrict_access_to_sysproc_auth_list_authorities_for_authid {
  db2_secured_setup { "restrict_access_to_sysproc_auth_list_authorities_for_authid on ${title}":
    ensure => 'present',
  }

  -> db2_secured::internal::revoke_public_grants { "${title}/SYSPROC.AUTHORIZATIONIDS": }
}
