#
# db2_secured::controls::review_roles_granted_to_public
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlGranting to `PUBLIC` increases the risk of unauthorized entry into the database. Because `PUBLIC` is accessible by any database user, it is important to understand the exposure it has on all database objects. It would make sense to grant role membership to `PUBLIC` if all users required all the privileges granted through that role.## RationaleAs any role granted to `PUBLIC` can potentially allow the compromise of database availability, confidentiality, or integrity, these roles should be restricted according to the needs of the business.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `db2_secured::controls::review_roles_granted_to_public: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `review_roles_granted_to_public` to the array value `db2_secured::skip_list` in your hiera data.  ## BenchmarksThis control is used in the following benchmarks:- [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 8.4
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::review_roles_granted_to_public {
  $elements = $title.split('/')
  $instance = $elements[0]
  $database = $elements[1]

  db2_secured_setup { "review_roles_granted_to_public on ${title}":
    ensure => 'present',
  }

  alert('Specified CIS control is not yet automatically enforced.')
}
