#
# db2_secured::controls::secure_connect_authority
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThe `CONNECT` role grants the authority to a user to connect to mainframe and midrange databases from Windows, Unix, and Linux operating systems. It is recommended that the `CONNECT` role be granted to authorized users only.## RationaleAll users that have access to this authority should be regularly reviewed.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `db2_secured::controls::secure_connect_authority: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `secure_connect_authority` to the array value `db2_secured::skip_list` in your hiera data.  ## BenchmarksThis control is used in the following benchmarks:- [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 7.13
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::secure_connect_authority (
  Array $user_list = db2_secured::lookup_setting('user_list', []),
  Array $group_list = db2_secured::lookup_setting('group_list', []),
) {
  db2_secured_setup { "secure_connect_authority on ${title}":
    ensure => 'present',
  }

  -> db2_secured::internal::revoke_right { "${title}/connect":
    user_list  => $user_list,
    group_list => $user_list,
  }
}
