#
# db2_secured::controls::secure_db2_runtime_library
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlA DB2 software installation will place all executables under the default <DB2PATH>\sqllib directory. This directory needs to be secured so it grants only the necessary access to authorized users and administrators.## RationaleThe DB2 runtime is comprised of files that are executed as part of the DB2 service. If these resources are not secured, an attacker may alter them to execute arbitrary code.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `db2_secured::controls::secure_db2_runtime_library: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `secure_db2_runtime_library` to the array value `db2_secured::skip_list` in your hiera data.  ## BenchmarksThis control is used in the following benchmarks:- [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 2.1
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::secure_db2_runtime_library {
  $elements = $title.split('/')
  $instance = $elements[0]
  $database = $elements[1]

  db2_secured_setup { "secure_db2_runtime_library on ${title}":
    ensure => 'present',
  }

  # lint:ignore:recurse_file
  range('0', '9').each |$no| {
    file { "/home/${instance}/NODE000${no}/sqldbdir]":
      mode    => '0755',
      recurse => true,
      require => Db2_secured_setup["secure_db2_runtime_library on ${title}"],
    }
  }
  # lint:endignore:recurse_file
}
