#
# db2_secured::controls::secure_sqladm_authority
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThe `SQLADM` authority is required to monitor, tune, and alter SQL statements.## RationaleThe `SQLADM` authority can `CREATE`, `SET`, `FLUSH`, `DROP EVENT MONITORS` and perform `RUNSTATS` and `REORG INDEXES` and `TABLES`. `SQLADM` can be granted to users, groups, or roles or `PUBLIC`. `SQLADM` authority is a subset of the `DBADM` authority and can be granted by the SECADM authority.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `db2_secured::controls::secure_sqladm_authority: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `secure_sqladm_authority` to the array value `db2_secured::skip_list` in your hiera data.  ## BenchmarksThis control is used in the following benchmarks:- [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 7.7
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::secure_sqladm_authority (
  Array $user_list = db2_secured::lookup_setting('user_list', []),
  Array $group_list = db2_secured::lookup_setting('group_list', []),
) {
  db2_secured_setup { "secure_sqladm_authority on ${title}":
    ensure => 'present',
  }

  -> db2_secured::internal::revoke_right { "${title}/sqladm":
    user_list  => $user_list,
    group_list => $user_list,
  }
}
