#
# db2_secured::controls::secure_sysmon_authority
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThe `sysmon_group` parameter defines the operating system groups with system monitor (SYSMON) authority. It is recommended that the `sysmon_group` group contain authorized users only.## RationaleIf an account that possesses this authority is compromised or used in a malicious manner, the confidentiality, integrity, and availability of data in the DB2 instance will be at increased risk.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `db2_secured::controls::secure_sysmon_authority: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `secure_sysmon_authority` to the array value `db2_secured::skip_list` in your hiera data.  ## BenchmarksThis control is used in the following benchmarks:- [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 7.4
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::secure_sysmon_authority (
  String[1] $preferred_value = db2_secured::lookup_setting('preferred_value', 'db2mon'),
  Array     $list            = db2_secured::lookup_setting('list', []),
) {
  db2_secured_setup { "secure_sysmon_authority on ${title}":
    ensure => 'present',
  }

  -> db2_secured::internal::secure_group { "${title}/sysmon_group":
    default_group => $preferred_value,
    list          => $list,
  }
}
