#
# db2_secured::controls::secure_the_communication_buffer_exit_library
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlA communication exit library is a dynamically loaded library that vendor applications use to examine communication buffers. The `comm_exit_list` parameter specifies the list of communication buffer exist libraries. The permissions on the libraries should be secured so that users other than the instance owner do not have write privileges.## RationaleIf a malicious user has write access to a communication exit library, they can overwrite it with their own thereby receiving all of the communication buffers that Db2 receives over the network. Securing the libraries will prevent a loss of confidentiality of data.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `db2_secured::controls::secure_the_communication_buffer_exit_library: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `secure_the_communication_buffer_exit_library` to the array value `db2_secured::skip_list` in your hiera data.  ## BenchmarksThis control is used in the following benchmarks:- [db11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 3.1.13
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::secure_the_communication_buffer_exit_library {
  $elements = $title.split('/')
  $instance = $elements[0]
  if  $facts['db2_instances'] {
    $home     = $facts['db2_instances'][$instance]['dftdbpath']

    db2_secured_setup { "secure_the_communication_buffer_exit_library on ${title}":
      ensure => 'present',
    }

    # lint:ignore:recurse_file
    file { ["${home}/security32/plugin/commexit", "${home}/security64/plugin/commexit"]:
      mode    => '0755',
      recurse => true,
      require => Db2_secured_setup["secure_the_communication_buffer_exit_library on ${title}"],
    }
    # lint:endignore:recurse_file
  } else {
    warning "Skipping this control until 'db2_instances' fact is filled"
  }
}
