#
# db2_secured::controls::secure_the_configuration_file
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlA configuration file, ekeystore.cfg, is created by the user in order to configure external keymanager functionality.This file should be secured against tampering via OS permissions.## RationaleSet this file to be readable and writeable by only the Db2 instance owner. If this file is not secured, an attacker may delete it, causing potential interruption of operations.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `db2_secured::controls::secure_the_configuration_file: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `secure_the_configuration_file` to the array value `db2_secured::skip_list` in your hiera data.  ## BenchmarksThis control is used in the following benchmarks:- [db11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 8.2.3
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::secure_the_configuration_file {
  db2_secured_setup { "secure_the_configuration_file on ${title}":
    ensure => 'present',
  }

  alert('Specified CIS control is not yet automatically enforced.')
}
