#
# db2_secured::controls::set_umask_value_in_the_db2_instance_owners_profile
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThe Db2 instance owner’s .profile file in Linux sets the environment variables and the settings for the user. This file is specific to the Korn shell and BASH shell, and other shells may have a different file.## RationaleThe umask value should be set to `022` for the owner of the Db2 software at all times to ensure files are not created with unnecessary privileges.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `db2_secured::controls::set_umask_value_in_the_db2_instance_owners_profile: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `set_umask_value_in_the_db2_instance_owners_profile` to the array value `db2_secured::skip_list` in your hiera data.  ## BenchmarksThis control is used in the following benchmarks:- [db11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 3.3.3
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::set_umask_value_in_the_db2_instance_owners_profile {
  $elements = $title.split('/')
  $instance = $elements[0]
  $database = $elements[1]

  db2_secured_setup { "set_umask_value_in_the_db2_instance_owners_profile on ${title}":
    ensure => 'present',
  }

  -> file_line { "umask set for instance ${instance}":
    path => "/home/${instance}/.bash_profile",
    line => 'umask 022',
  }
}
