#
# db2_secured::controls::turn_off_remote_command_legacy_mode
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThe `DB2RCMD_LEGACY_MODE` registry variable determines whether the Db2 Remote Command Service runs with enhanced security or not. It is recommended that legacy mode not be enabled.This registry variable only applies to Db2 Servers running on Windows.## RationaleLegacy mode requires the Db2 service account to have privileges to impersonate the client account.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `db2_secured::controls::turn_off_remote_command_legacy_mode: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `turn_off_remote_command_legacy_mode` to the array value `db2_secured::skip_list` in your hiera data.  ## BenchmarksThis control is used in the following benchmarks:- [db11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 3.2.2
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::turn_off_remote_command_legacy_mode {
  db2_secured_setup { "turn_off_remote_command_legacy_mode on ${title}":
    ensure => 'present',
  }

  if $facts['kernel'] == 'Windows' {
    alert('Specified CIS control is not yet automatically enforced.')
  } else {
    debug('Specified CIS control is not applicable on current kernel')
  }
}
