#
# db2_secured::validators::enable_ssl_communication_with_ldap_server
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# The communication layer between a DB2 instance and the LDAP server should be encrypted. It is recommended that the `ENABLE_SSL` parameter in the `IBMLDAPSecurity.ini` file be set to TRUE.
# 
# 
# ## Rationale
# 
# Enabling SSL will help ensure the confidentiality of authentication credentials and other information that is sent between the DB2 instance and the LDAP server.
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `db2_secured::validators::enable_ssl_communication_with_ldap_server: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `enable_ssl_communication_with_ldap_server` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 9.5
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::validators::enable_ssl_communication_with_ldap_server (
  Boolean   $skip      = db2_secured::lookup_setting('skip', false),
  String[1] $report_as = db2_secured::lookup_setting('report_as', 'warning'),
) {
  db2_secured_setup { "enable_ssl_communication_with_ldap_server validation on ${title}":
    ensure => 'present',
  }
  alert('Specified CIS validator cannot yet be validated')
}
