#
# db2_secured::validators::set_maximum_connection_limits_max_connections_and_max_coordagents
#
# @summary Puppet validators are Puppet defined types that inspect the system and reports when the systems deviates from the specified security control.
# These Puppet defined
# types make **NO* changes to you system, they only report deviations.
# 
# ## Desription
# 
# TODO: Write documentation
# 
# 
# ## Rationale
# 
# 
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with two ways:
# 
# 1) Add `db2_secured::validators::set_maximum_connection_limits_max_connections_and_max_coordagents: skip` to your hiera data. This will skip this control for **ALL** systems.  
# 3) Add an entry with the content `set_maximum_connection_limits_max_connections_and_max_coordagents` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [db11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 3.1.8
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::validators::set_maximum_connection_limits_max_connections_and_max_coordagents (
  Boolean   $skip      = db2_secured::lookup_setting('skip', false),
  String[1] $report_as = db2_secured::lookup_setting('report_as', 'warning'),
) {
  $instance = split($title, '/')[0]
  if $facts['db2_instances'] {
    $max_coordagents = dig($facts['db2_instances'][$instance], 'max_coordagents')
    $max_connections = dig($facts['db2_instances'][$instance], 'max_connections')

    if $max_coordagents and $max_connections {
      db2_secured_setup { "set_maximum_connection_limits_max_connections_and_max_coordagents validation on ${title}":
        ensure => 'present',
      }
      -> validation { "maximum connection limits should be SET CORRECTLY on ${instance}":
        check           => "echo \"${max_coordagents},${max_connections}\"",
        path            => '/bin',
        expected_output => /\d*,-1/,
        report_as       => $report_as,
        skip            => $skip,
        control         => easy_type::current_control(),
        fail_message    => "maximum connection limits is NOT SET CORRECTLY on ${instance}",
      }
    } else {
      warning "maximum connection limits (max_connections) or maximum number of coordinating agents (max_coordagents) not set on ${instance}"
    }
  } else {
    warning "Skipping this validator until 'db2_instances' fact is filled"
  }
}
