#
# db2_secured::controls::restrict_access_to_syscat_routineauth
#
# @summary 
# Puppet controls are Puppet defined types that ensure a certain security control is implemented. Puppet changes the system in order to make the system compliant.## Description of the controlThe `SYSCAT.ROUTINEAUTH` view contains a list of all users that have `EXECUTE`  privilege on a routine (function, method, or procedure). It is recommended that the `PUBLIC` role be restricted from accessing this view.## Rationale`PUBLIC` should not have access to see all the users because this could be used as a point of exploit.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with two ways:1) Add `db2_secured::controls::restrict_access_to_syscat_routineauth: skip` to your hiera data. This will skip this control for **ALL** systems.  3) Add an entry with the content `restrict_access_to_syscat_routineauth` to the array value `db2_secured::skip_list` in your hiera data.  ## BenchmarksThis control is used in the following benchmarks:- [db10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 6.17- [db11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 4.2.22
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::restrict_access_to_syscat_routineauth {
  db2_secured_setup { "restrict_access_to_syscat_routineauth on ${title}":
    ensure => 'present',
  }

  -> db2_secured::internal::revoke_public_grants { "${title}/SYSCAT.ROUTINEAUTH": }
}
